@@ -4,7 +4,7 @@
  * Start Date:  Wed Nov 29 23:08:24 1995
  * Project:     INN (innfeed)
  * File:        endpoint.c
- * RCSId:       $Id: endpoint.c,v 1.12 1996/05/23 21:18:24 brister Exp brister $
+ * RCSId:       $Id: endpoint.c,v 1.14 1996/08/20 12:27:35 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -38,7 +38,7 @@
  */
 
 #if ! defined (lint)
-static char rcsid [] = "$Id: endpoint.c,v 1.12 1996/05/23 21:18:24 brister Exp brister $" ;
+static char rcsid [] = "$Id: endpoint.c,v 1.14 1996/08/20 12:27:35 brister Exp $" ;
 static void use_rcsid (const char *rId) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rId) ;
 } 
@@ -90,15 +90,15 @@ struct timeval
 #endif
 
 
-#if ! defined (UIO_MAXIOV) && defined (MAX_IOVEC)
-#define UIO_MAXIOV MAX_IOVEC
+#if ! defined (UIO_MAXIOV) && defined (MAX_WRITEV_VEC)
+#define UIO_MAXIOV MAX_WRITEV_VEC
 #elif ! defined (UIO_MAXIOV) && defined (DEF_MAX_IOV) /* svr4 */
 #define UIO_MAXIOV DEF_MAX_IOV
 #endif
 
 
 #if ! defined (UIO_MAXIOV)
-#error Neither UIO_MAXIOV nor MAX_IOVEC are defined -- see sysconfig.h
+#error Neither UIO_MAXIOV nor MAX_WRITEV_VEC are defined -- see sysconfig.h
 #endif
 
 
@@ -428,7 +428,7 @@ TimeoutId prepareWake (EndpTCB func, time_t timeToWake, void *clientData)
   
   timeToSleep = timeToWake - now ;
   
-  timerElemAdd (timeToWake,func,clientData) ;
+  id = timerElemAdd (timeToWake,func,clientData) ;
 
 #if 0
   dprintf (1,"Preparing wake %d at date %ld for %d seconds\n",
@@ -731,7 +731,7 @@ static IoStatus doRead (EndPoint endp)
   for (i = currIdx ; buffers && buffers [i] != NULL ; i++)
     bCount++ ;
 
-  /* if UIO_MAXIOV is undefined then set MAX_IOVEC in config.h */
+  /* if UIO_MAXIOV is undefined then set MAX_WRITEV_VEC in config.h */
   bCount = (bCount > UIO_MAXIOV ? UIO_MAXIOV : bCount) ;
 
   i = 0 ;
@@ -852,7 +852,7 @@ static IoStatus doWrite (EndPoint endp)
   for (i = currIdx ; buffers && buffers [i] != NULL ; i++)
     bCount++ ;
 
-  /* if UIO_MAXIOV is undefined then set MAX_IOVEC in config.h */
+  /* if UIO_MAXIOV is undefined then set MAX_WRITEV_VEC in config.h */
   bCount = (bCount > UIO_MAXIOV ? UIO_MAXIOV : bCount) ;
 
   i = 0 ;
@@ -952,7 +952,11 @@ static IoStatus doExcept (EndPoint endp)
   else
     syslog (LOG_ERR,UNKNOWN_EXCEPTION,fd) ;
 
+  sleep (5) ;
   abort () ;
+
+  /* Not reached */
+  return IoFailed ;
 }
 
 #if 0
@@ -964,17 +968,14 @@ static void endPointPrint (EndPoint ep, FILE *fp)
 
 static void intHandler (int s)
 {
-  (void) s ;                    /* keep lint happy */
-
   sigFlag = 1 ;
+  signal (s, intHandler) ;
 }
 
 
 static void pipeHandler (int s)
 {
-  (void) s ;                    /* keep lint happy */
-  
-  /* do nothing */
+  signal (s, pipeHandler) ;
 }
 
 
