@@ -4,7 +4,7 @@
  * Start Date:  Thu Dec 28 17:29:05 1995
  * Project:     INN (innfeed)
  * File:        host.c
- * RCSId:       $Id: host.c,v 1.16 1996/06/05 13:59:01 brister Exp brister $
+ * RCSId:       $Id: host.c,v 1.18 1996/08/20 12:29:22 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: host.c,v 1.16 1996/06/05 13:59:01 brister Exp brister $" ;
+static const char *rcsid = "$Id: host.c,v 1.18 1996/08/20 12:29:22 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -77,6 +77,7 @@ struct host_s
     u_int initialCxns ;         /* number of connections to create at start */
     Connection blockedCxn ;     /* the first connection to get the 400 banner*/
 
+    bool wantStreaming ;        /* true if config file says to stream. */
     bool remoteStreams ;        /* true if remote supports streaming */
     
     u_int maxChecks ;           /* max number of CHECK commands to send */
@@ -208,6 +209,7 @@ Host newHost (InnListener listener,
               u_int maxCheck,
               u_short portNum,
               u_int closePeriod,
+              bool streaming,
               double lowPassHigh,
               double lowPassLow) 
 {
@@ -243,6 +245,7 @@ Host newHost (InnListener listener,
   nh->articleTimeout = artTimeout ;
   nh->responseTimeout = respTimeout ;
   nh->port = portNum ;
+  nh->wantStreaming = streaming ;
 
   nh->queued = NULL ;
   nh->queuedTail = NULL ;
@@ -646,8 +649,10 @@ void hostRemoteStreams (Host host, Connection cxn, bool doesStreaming)
   
   if (host->connectTime == 0)   /* first connection for this cycle. */
     {
-      if (doesStreaming)
+      if (doesStreaming && host->wantStreaming)
         syslog (LOG_NOTICE, REMOTE_DOES_STREAMING, host->peerName);
+      else if (doesStreaming)
+        syslog (LOG_NOTICE, REMOTE_STREAMING_OFF, host->peerName);
       else
         syslog (LOG_NOTICE, REMOTE_NO_STREAMING, host->peerName);
 
@@ -659,13 +664,13 @@ void hostRemoteStreams (Host host, Connection cxn, bool doesStreaming)
         clearTimer (host->statsId) ;
       host->statsId = prepareSleep (hostStatsTimeoutCbk, statsPeriod, host) ;
 
-      host->remoteStreams = doesStreaming ;
+      host->remoteStreams = (host->wantStreaming ? doesStreaming : false) ;
 
       host->connectTime = theTime() ;
       if (host->firstConnectTime == 0)
         host->firstConnectTime = host->connectTime ;
     }
-  else if (host->remoteStreams != doesStreaming)
+  else if (host->remoteStreams != doesStreaming && host->wantStreaming)
     syslog (LOG_NOTICE,STREAMING_CHANGE,host->peerName) ;
 
   for (i = 0 ; i < host->maxConnections ; i++)
@@ -1095,6 +1100,13 @@ const char *hostPeerName (Host host)
 }
 
 
+/* return true if the Connections for this host should attempt to do
+   streaming. */
+bool hostWantsStreaming (Host host)
+{
+  return host->wantStreaming ;
+}
+
 u_int hostMaxChecks (Host host)
 {
   return host->maxChecks ;
@@ -1418,9 +1430,9 @@ static void hostPrintStatus (Host host, FILE *fp)
   if (host->firstConnectTime > 0)
     fprintf (fp,"    seconds %ld offered %ld accepted %ld refused %ld rejected %ld missing %ld\n\n",
              (long) (now - host->firstConnectTime),
-             (long) host->artsOffered, (long) host->artsAccepted,
-             (long) host->artsNotWanted, (long) host->artsRejected,
-             (long) host->artsMissing) ;
+             (long) host->gArtsOffered, (long) host->gArtsAccepted,
+             (long) host->gArtsNotWanted, (long) host->gArtsRejected,
+             (long) host->gArtsMissing) ;
   else
     fprintf (fp,"\n") ;
 }
