@@ -4,7 +4,7 @@
  * Start Date:  Thu Dec 28 13:15:04 1995
  * Project:     INN (innfeed)
  * File:        innlistener.c
- * RCSId:       $Id: innlistener.c,v 1.16 1996/06/05 14:02:58 brister Exp brister $
+ * RCSId:       $Id: innlistener.c,v 1.18 1996/08/20 14:07:47 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: innlistener.c,v 1.16 1996/06/05 14:02:58 brister Exp brister $" ;
+static const char *rcsid = "$Id: innlistener.c,v 1.18 1996/08/20 14:07:47 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -85,6 +85,8 @@ static void giveArticleToPeer (InnListener lis,
 static void newArticleCommand (EndPoint ep, IoStatus i,
                                Buffer *buffs, void *data) ;
 static void logBadPeer (const char *peer) ;
+static bool isBadPeer (const char *peer) ;
+static void rememberBadPeer (const char *peer) ;
 
 
 
@@ -288,8 +290,6 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
   
   if (i == IoEOF || i == IoFailed)
     {
-      freeBufferArray (buffs) ;
-
       if (i == IoEOF)
         {
           dprintf (1,"Got EOF on listener\n") ;
@@ -439,18 +439,17 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
 /*
  * Log the name of the bad peer. One time only.
  */
-static void logBadPeer (const char *peer)
-{
-  static char **peers ;
-  static u_int peerLen ;
-  static u_int peerIdx ;
+static char **peers ;
+static u_int peerLen ;
+static u_int peerIdx ;
 
+static void rememberBadPeer (const char *peer)
+{
   u_int i ;
 
-  for (i = 0 ; i < peerIdx ; i++)
-    if (strcmp (peer,peers [i]) == 0)
-      return ;
-
+  if (isBadPeer (peer))         /* check if we already logged it. */
+    return ;
+  
   if (i == peerIdx && peerIdx == peerLen)
     {
       peerLen += 10 ;
@@ -462,10 +461,31 @@ static void logBadPeer (const char *peer)
 
   if (i == peerIdx)
     peers [peerIdx++] = strdup (peer) ;
+}
 
+static void logBadPeer (const char *peer)
+{
+  if (isBadPeer (peer))
+    return ;
+  
+  rememberBadPeer (peer) ;
   syslog (LOG_ERR,UNKNOWN_PEER,peer) ;
 }
 
+
+static bool isBadPeer (const char *peer)
+{
+  bool rval = true ;
+  int i ;
+  
+  for (i = 0 ; i < peerIdx ; i++)
+    if (strcmp (peer,peers [i]) == 0)
+      rval = false ;
+
+  return rval ;
+}
+
+
 /* Find the Host object for the peer and hand off a reference to the
    article for it to transmit. */
 static void giveArticleToPeer (InnListener lis,
@@ -486,14 +506,16 @@ static void giveArticleToPeer (InnListener lis,
     {
       dprintf (1,"Failed to give article to peer: -%s-\n", peerName) ;
       
-      if (lis->dynamicPeers)
+      if (lis->dynamicPeers && !isBadPeer (peerName))
         {
           u_int articleTout ;
           u_int respTout ;
           u_int initialCxns ;
           u_int maxCxns ;
           u_int maxChecks ;
-          bool immedOpen ;
+          bool streaming ;
+          double lowFilter ;
+          double highFilter ;
           u_short portNum ;
           Host newHostObj ;
 
@@ -502,22 +524,31 @@ static void giveArticleToPeer (InnListener lis,
           syslog (LOG_NOTICE,DYNAMIC_PEER,peerName) ;
 
           getHostDefaults (&articleTout, &respTout, &initialCxns,
-                           &maxCxns, &maxChecks, &immedOpen, &portNum) ;
+                           &maxCxns, &maxChecks, &streaming,
+                           &lowFilter, &highFilter, &portNum) ;
 
           newHostObj = newHost (lis, peerName, peerName,
                                 articleTout, respTout, initialCxns,
-                                maxCxns, maxChecks, portNum,
-                                CLOSE_PERIOD, LOW_PASS_FILTER_ON,
-                                LOW_PASS_FILTER_OFF) ;
+                                maxCxns, maxChecks, portNum, CLOSE_PERIOD,
+                                streaming, lowFilter, highFilter);
 
-          if ( !listenerAddPeer (lis, newHostObj) )
-              /* XXX need to remember ew've gone over the limit and not try
+          if (newHostObj == NULL)
+            {
+              /* XXX I need to handle this better. */
+              rememberBadPeer (peerName) ;
+              syslog (LOG_ERR,NO_HOST,peerName) ;
+            }
+          else if ( !listenerAddPeer (lis, newHostObj) )
+            {
+              /* XXX need to remember we've gone over the limit and not try
                  to add any more. */
-            syslog (LOG_ERR, TOO_MANY_HOSTS, lis->hostLen) ;
+              rememberBadPeer (peerName) ;
+              syslog (LOG_ERR, TOO_MANY_HOSTS, lis->hostLen) ;
+            }
           else
             hostSendArticle (newHostObj,artTakeRef (article)) ;
         }
-      else
+      else if ( !isBadPeer (peerName) )
         logBadPeer (peerName) ;
     }
 }
