@@ -4,7 +4,7 @@
  * Start Date:  Sun, 28 Jan 1996 18:37:49 +1100
  * Project:     INN -- innfeed
  * File:        msgs.h
- * RCSId:       $Id: msgs.h,v 1.14 1996/06/05 14:04:14 brister Exp brister $
+ * RCSId:       $Id: msgs.h,v 1.16 1996/08/20 13:40:39 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -66,6 +66,10 @@
 #define CONNECTION_FAILURE      "%s:%d cxnsleep connect : %m"
 #define IO_FAILED               "%s:%d cxnsleep i/o failed : %m"
 #define NO_TRANSFER_NNRPD	"%s:%d cxnsleep transfer permission denied"
+#define NO_TALK_NNRPD		"%s:%d cxnsleep no permission to talk"
+#define CXN_BAD_STATE		"%s:%d cxnsleep connection in bad state: %s"
+#define CXN_STREAM_RESP		"%s:%d cxnsleep unexpected streaming response for non-streaming connection: %s"
+#define CXN_NONSTREAM_RESP	"%s:%d cxnsleep unexpected non-streaming response for streaming connection: %s"
 
 #define MAX_ARTTOUT_BIG         "%s:%d config max article timeout value too big: %d"
 #define MAX_RESPTOUT_BIG        "%s:%d config response timeout value too big: %d"
@@ -103,6 +107,7 @@
 #define BACKLOG_TO_TAPE         "%s spooling some backlog."
 #define SPOOL_DEFERRED          "%s spooling deferred articles"
 #define REMOTE_DOES_STREAMING   "%s remote MODE STREAM"
+#define REMOTE_STREAMING_OFF	"%s remote MODE STREAM disabled"
 #define REMOTE_NO_STREAMING     "%s remote MODE STREAM failed"
 #define STREAMING_CHANGE        "%s remote MODE STREAM change"
 
@@ -137,6 +142,7 @@
 
 /* article.c */
 
+#define DOUBLE_NAME             "ME two filenames for same article: %s: %s"
 #define BAD_ART_READ            "ME article read-error : %s : %m"
 #define NO_ARTICLE              "ME article missing : %s : %s"
 #define FSTAT_FAILURE           "ME oserr fstat %s : %m"
@@ -164,6 +170,7 @@
 #define CD_FAILED               "ME fatal chdir %s : %m"
 #define NO_SNAPSHOT		"ME config ignored snapshot file: %s : %m"
 #define BATCH_AND_NO_CXNS	"%s config ignored batch mode with initial connection count of 0"
+#define LOW_GREATER		"%s config low-pass lower limit greater than upper limit"
 
 
 /* misc.c */
